% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/climate_seg.R
\name{climate_seg}
\alias{climate_seg}
\title{Segmenting climate and environmental data}
\usage{
climate_seg(env.data, dm.stats, value = c("mean", "min",
            "max", "sum"))
}
\arguments{
\item{env.data}{a \code{data.frame} with with a timestamp (\code{\%Y-\%m-\%d \%H:\%M:\%S} format) as row names, and a certain climate parameter (e.g., temperature or precipitation) in columns.}

\item{dm.stats}{a \code{list} as produced by \code{\link{cycle_stats}}.}

\item{value}{a \code{character} string of \code{"mean"}, \code{"min"}, \code{"max"} or \code{"sum"}, specifying whether means (e.g., for temperature) or sums (e.g., for precipitation) should be calculated, or minimum or maximum values should be extracted. Defaults to \code{"mean"}. Argument matching is performed.}
}
\value{
The function returns a \code{data.frame} with segmented environmental data. The \code{data.frame} contains the following columns:
\item{dmID}{dendrometer ID.}
\item{cycle}{cycle number.}
\item{phase}{cyclic phase (1: contraction, 2: expansion, 3: stem-radius increment, 4: full cycle).}
\item{begin}{timestamp indicating the beginning of each phase.}
\item{end}{timestamp indicating the end of each phase.}
\item{...}{columns with segmented environmental data (mean, min, max or sum).}
}
\description{
The function calculates means or sums, or extracts minimum or maximum values of environmental parameters for stem-cyclic phases as defined using \code{\link{cycle_stats}}.
}
\details{
The function segments environmental parameters according to the stem-cyclic phases as defined using \code{\link{cycle_stats}}. Means, sums, and minimum and maximum values can be calculated or extracted.

\code{env.data} should cover at least the same period as the dendrometer data used to define the cyclic phases, and should have the same (or a higher) temporal resolution.
}
\examples{
\donttest{
data(dmED)
dm.gpf <- fill_gaps(dmED)
dm.phase <- phase_def(dm.gpf)
dm.stats <- cycle_stats(dm.gpf, dm.phase)
data(envED)
clim.phase <- climate_seg(envED, dm.stats, value = "mean")
}

}
